/*
 * Interface file for a number of functions to determine the path to the app.
 * in a cross platform manner...
 */

#ifndef HAVE_GET_APP_PATH_H
#define HAVE_GET_APP_PATH_H   1

#ifndef tidy
/******************************************************************************
* Name:        tidy
* Checks for any still malloc'd memory and releases it.
* Easier to do as a macro than a function!
*******************************************************************************/
#define tidy(mem)  {if(mem){free(mem); mem = NULL;}} /* tidy */
#endif

#ifdef __APPLE__ /* assume this is OSX */
# ifndef PATH_MAX
#  define PATH_MAX MAXPATHLEN
# endif
#endif /* APPLE */

#ifndef PATH_MAX
#  define PATH_MAX 2048
#endif

/********************************************************************************************/
/* Allow C++ Portability */
#ifdef __cplusplus
extern "C" {
#endif

/* 
 * Returns the path to the current app in pname, that should be at least 
 * MAXPATHLEN long - actual size of buffer should be in pathsize
 */
int get_app_path (char *pname, size_t pathsize);

/* Allow C++ Portability */
#ifdef __cplusplus
}
#endif

#endif // HAVE_GET_APP_PATH_H //

/********************************************************************************************/
/* End of File */
